@@ -373,6 +373,8 @@ class Eniam():
         for key in lexicon:
             if hasattr(lexicon[key], 'rule'):
                 lexicon[key] = lexicon[key].rule()
+            if '|rule_id|' in lexicon[key]:
+                lexicon[key] = lexicon[key].split('|rule_id|')[1]
 
         lexicon_custom = []
         for key in lexicon:
